sessionDirName top-level constant
String
const sessionDirName
Name of the session directory created inside the Flutter project.
Implementation
const sessionDirName = '.fdb';
Name of the session directory created inside the Flutter project.
const sessionDirName = '.fdb';