core/commands/attach/attach library

Classes

AttachControllerFailed
The controller process failed to start.
AttachError
Generic / unrecognised error.
AttachMissingDevice
No --device was provided.
AttachProcessDied
The attach process exited before the VM service URI appeared.
AttachResult
Result of an attachApp invocation.
AttachSuccess
App attached successfully. VM service is reachable at vmServiceUri.
AttachTimeout
The VM service URI did not appear within the launch timeout.

Functions

attachApp(AttachInput input, {void onProgress(String) = _noop}) Future<AttachResult>
Attaches fdb to an already-running Flutter app and waits for the VM service.
buildAttachControllerArgs(List<String> controllerEntrypointArgs, {required String sessionDir, required String project, required String device, required String flutter, String? target, String? appId, String? debugUrl, required bool verbose}) List<String>
discoverVmServiceUrl({required String device, required ({bool emulator, String platform}) platformInfo, Duration timeout = const Duration(seconds: 5), void onProgress(String) = _noop}) Future<String?>
Attempts to discover the Dart VM service URL for a Flutter app that was launched outside of fdb by scanning the relevant device log.
normalizeAttachDebugUrl(String debugUrl) String

Typedefs

AttachInput = ({String? appId, String? debugUrl, String? device, String? flavor, String? flutterSdk, bool interactive, String? project, String? sessionDir, String? target, bool verbose})
Input parameters for attachApp.