core/commands/attach/vm_uri_discovery library

Functions

discoverVmServiceUrl({required String device, required ({bool emulator, String platform}) platformInfo, Duration timeout = const Duration(seconds: 5), void onProgress(String) = _noop}) Future<String?>
Attempts to discover the Dart VM service URL for a Flutter app that was launched outside of fdb by scanning the relevant device log.
extractVmUriFromLog(String text) String?
Scans text for a Dart VM service URI and returns the normalised HTTP URL, or null if none is found.