core/commands/clean/clean_models library

Classes

CleanAppDied
The app process died while fdb was communicating with it.
CleanError
The VM service extension returned an error message.
CleanNoFdbHelper
fdb_helper was not detected in the running app.
CleanResult
Result of a cleanApp invocation.
CleanSuccess
Cache directories were successfully cleaned.
CleanUnexpectedResponse
The VM service returned an unexpected response shape.

Typedefs

CleanInput = ()
Input parameters for cleanApp. Empty record because fdb clean takes no arguments today.