CleanSuccess class

Cache directories were successfully cleaned.

Inheritance

Constructors

CleanSuccess({required List<String> dirs, required int deletedEntries})
const

Properties

deletedEntries int
final
dirs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited