core/commands/describe/describe library
Classes
- DescribeAppDied
- The app process died while fdb was communicating with it.
- DescribeError
- Generic / unrecognised error.
- DescribeNoFdbHelper
- fdb_helper was not detected in the running app.
- DescribeRelayedError
-
The extension returned an error string in the
errorfield. - DescribeResult
- Result of a describeScreen invocation.
- DescribeSuccess
- ext.fdb.describe responded with a valid payload.
- DescribeUnexpectedResponse
-
The VM service returned a response that is not a
Map<String, dynamic>.
Functions
-
describeScreen(
DescribeInput _) → Future< DescribeResult> - Returns a compact snapshot of the current screen via ext.fdb.describe.
Typedefs
- DescribeInput = ()
-
Input parameters for describeScreen. Empty record because
fdb describetakes no arguments.