core/commands/describe/describe_models library

Classes

DescribeAppDied
The app process died while fdb was communicating with it.
DescribeError
Generic / unrecognised error.
DescribeNoFdbHelper
fdb_helper was not detected in the running app.
DescribeRelayedError
The extension returned an error string in the error field.
DescribeResult
Result of a describeScreen invocation.
DescribeSuccess
ext.fdb.describe responded with a valid payload.
DescribeUnexpectedResponse
The VM service returned a response that is not a Map<String, dynamic>.

Typedefs

DescribeInput = ()
Input parameters for describeScreen. Empty record because fdb describe takes no arguments.