DescribeSuccess class

ext.fdb.describe responded with a valid payload.

Inheritance

Constructors

DescribeSuccess(Map<String, dynamic> raw)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
raw Map<String, dynamic>
The raw map returned by ext.fdb.describe (screen, route, interactive, texts).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited