HeapDumpSuccess class
Snapshot captured and written to outputPath.
- Inheritance
-
- Object
- CommandResult
- HeapDumpResult
- HeapDumpSuccess
Constructors
- HeapDumpSuccess({required String outputPath, required int bytes})
-
const
Properties
- bytes → int
-
Total bytes written.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputPath → String
-
Absolute path of the written snapshot file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited