InputSuccess class

Text was entered and/or an IME action was sent.

fieldType is the widget type string. value is the entered text (null when only an action was sent). action is the IME action performed, if any. clientType is the State that received the input (e.g. EditableTextState, QuillRawEditorState).

Inheritance

Constructors

InputSuccess({required String fieldType, required String? value, String? action, String? clientType})
const

Properties

action → String?
final
clientType → String?
final
fieldType → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited