LaunchTimeout class

The VM service URI did not appear within launchTimeoutSeconds. tailLogLines contains the last 10 lines of the log (may be empty).

Inheritance

Constructors

LaunchTimeout({List<String> tailLogLines = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tailLogLines → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited