LogsStream class

Lines are available for consumption.

For snapshot mode, lines is a finite Stream.fromIterable and exitCode resolves immediately to 0. cancel is a no-op.

For follow mode, lines is a live StreamController that polls the log file every 500 ms. cancel stops polling and closes the controller. exitCode resolves to 0 after cancel is called.

Inheritance

Constructors

LogsStream({required Stream<String> lines, required Future<int> exitCode, required Future<void> cancel()})
const

Properties

cancel → Future<void> Function()
final
exitCode → Future<int>
final
hashCode → int
The hash code for this object.
no setterinherited
lines → Stream<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited