LongpressSuccess class

Inheritance

Constructors

LongpressSuccess({required String widgetType, required dynamic x, required dynamic y})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetType String
'coordinates' if LongpressInput.usedAt was true, otherwise the widget type returned by the VM extension (or a fallback).
final
x → dynamic
final
y → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited