ClassAlloc class

Per-class allocation record inside a profile snapshot.

Constructors

ClassAlloc({required String className, required String libraryUri, required int instancesCurrent, required int bytesCurrent})
const

Properties

bytesCurrent int
final
className String
final
hashCode int
The hash code for this object.
no setterinherited
instancesCurrent int
final
libraryUri String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited