MemDiffSuccess class

Diff computed successfully.

Inheritance

Constructors

MemDiffSuccess({required List<ClassDiff> diffs, required String beforeIsolateName, required String afterIsolateName, required MemDiffSort sort})
const

Properties

afterIsolateName String
final
beforeIsolateName String
final
diffs List<ClassDiff>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort MemDiffSort
The sort key applied — callers use this to label the output correctly.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited