MemProfile class

A full allocation profile captured by getAllocationProfile.

Constructors

MemProfile({required String isolateId, required String isolateName, required DateTime capturedAt, required List<ClassAlloc> classes})
const

Properties

capturedAt → DateTime
final
classes → List<ClassAlloc>
final
hashCode → int
The hash code for this object.
no setterinherited
isolateId → String
final
isolateName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MemProfile
Parses a profile from JSON produced by toJson.