MemProfileSuccess class
Profile captured and written to disk (single isolate).
- Inheritance
-
- Object
- CommandResult
- MemProfileResult
- MemProfileSuccess
Constructors
- MemProfileSuccess({required String outputPath, required int classCount, required String isolateName})
-
const
Properties
- classCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateName → String
-
final
- outputPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited