AndroidBounds class

A [left,top][right,bottom] rectangle in physical pixels.

Constructors

AndroidBounds(int left, int top, int right, int bottom)
const

Properties

bottom → int
final
centerX → int
no setter
centerY → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
no setter
left → int
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override