AndroidUiDumpInvalid class

The dump is unusable. reason says why, e.g. the ERROR: could not get idle state. line uiautomator prints (with exit code 0) while the screen is animating.

Inheritance

Constructors

AndroidUiDumpInvalid(String reason)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited