AndroidUiDumpParsed class

The dump held a complete <hierarchy>; nodes are in document order.

Inheritance

Constructors

AndroidUiDumpParsed(List<AndroidUiNode> nodes)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodes → List<AndroidUiNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited