NativeTapAdbFailed class

adb shell input tap failed: non-zero exit, or an exception in its output with exit code 0.

Inheritance

Constructors

NativeTapAdbFailed(String details)
const

Properties

details → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited