NativeTapAmbiguous class
Several native elements matched query and no --index was given.
- Inheritance
-
- Object
- CommandResult
- NativeTapResult
- NativeTapAmbiguous
Constructors
-
NativeTapAmbiguous({required String query, required List<
NativeTapCandidate> candidates}) -
const
Properties
-
candidates
→ List<
NativeTapCandidate> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited