NativeTapIndexOutOfRange class

--index is past the last of the count matches for query.

Inheritance

Constructors

NativeTapIndexOutOfRange({required String query, required int index, required int count})
const

Properties

count → int
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
query → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited