NativeTapNoMatch class

No native element matched query before the timeout. visibleLabels are the labels in the last window dump (Android) or accessibility tree (iOS simulator), in screen order.

Inheritance

Constructors

NativeTapNoMatch({required String query, required List<String> visibleLabels})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
query → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleLabels → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited