NativeTapResult class sealed
Result of a nativeTap invocation.
- Inheritance
-
- Object
- CommandResult
- NativeTapResult
- Implementers
- NativeTapAdbExecutionFailed
- NativeTapAdbFailed
- NativeTapAmbiguous
- NativeTapAndroid
- NativeTapDevicePixelRatioUnavailable
- NativeTapIndexOutOfRange
- NativeTapInputInjectionBlocked
- NativeTapIosSimulator
- NativeTapIosSimulatorAccessibilityUnavailable
- NativeTapIosSimulatorFailed
- NativeTapIosSimulatorFallback
- NativeTapIosSimulatorFramesUnmapped
- NativeTapIosSimulatorOrientationUnknown
- NativeTapIosSimulatorOutOfBounds
- NativeTapIosSimulatorTapUnavailable
- NativeTapIosSimulatorTreeUnreadable
- NativeTapMacosUnsupported
- NativeTapNoMatch
- NativeTapNoSession
- NativeTapPhysicalIosUnsupported
- NativeTapPlatformUnsupported
- NativeTapUiDumpFailed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited