RestartProcessDead class
The PID file exists but the process is no longer alive.
- Inheritance
-
- Object
- CommandResult
- RestartResult
- RestartProcessDead
Constructors
- RestartProcessDead({required int pid})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited