ScreenshotSaved class

Screenshot was captured, optionally downscaled, and saved to path.

Inheritance

Constructors

ScreenshotSaved({required String path, required int sizeBytes, List<String> warnings = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final
warnings List<String>
Accumulated WARNING lines (already prefixed with "WARNING: …").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited