core/commands/scroll/scroll_models library

Classes

ScrollAppDied
The app process died while fdb was communicating with it.
ScrollDirectionMode
Direction-based scroll: fdb scroll down [--at x,y] [--distance pixels].
ScrollDirectionSuccess
Direction scroll succeeded.
ScrollError
Generic / unrecognised error.
ScrollInput
ScrollNoFdbHelper
fdb_helper was not detected in the running app.
ScrollRawMode
Raw coordinate drag: fdb scroll --from x,y --to x,y.
ScrollRawSuccess
Raw coordinate drag succeeded.
ScrollRelayedError
The VM service returned an error message relayed from the extension.
ScrollResult
ScrollUnexpectedResponse
The VM service returned an unexpected response shape.