ScrollRawMode class

Raw coordinate drag: fdb scroll --from x,y --to x,y.

Inheritance

Constructors

ScrollRawMode({required double fromX, required double fromY, required double toX, required double toY})
const

Properties

fromX → double
final
fromY → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toX → double
final
toY → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited