ScrollRawSuccess class

Raw coordinate drag succeeded.

Inheritance

Constructors

ScrollRawSuccess({required int fromX, required int fromY, required int toX, required int toY})
const

Properties

fromX → int
final
fromY → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toX → int
final
toY → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited