core/commands/scroll_to/scroll_to library

Classes

ScrollToAppDied
The app process died while fdb was communicating with it.
ScrollToError
Generic / unrecognised error.
ScrollToMissingCoordinates
The VM service returned a success status but x or y was missing.
ScrollToNoFdbHelper
fdb_helper was not detected in the running app.
ScrollToRelayedError
The VM service returned an error message.
ScrollToResult
Result of a scrollTo invocation.
ScrollToSuccess
The scroll succeeded and the target widget is now visible.
ScrollToUnexpectedResponse
The VM service returned an unexpected response shape.

Functions

scrollTo(ScrollToInput input) Future<ScrollToResult>
Scrolls the nearest Scrollable until the target widget becomes visible.

Typedefs

ScrollToInput = ({int? index, String? key, String? text, String? type})
Input parameters for scrollTo.