SelectAppDied class
The app process died while fdb was communicating with it.
- Inheritance
-
- Object
- CommandResult
- SelectResult
- SelectAppDied
Constructors
-
SelectAppDied({required List<
String> logLines, String? reason}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited