SelectedWidget class
A widget is selected; carries its description and optional source location.
- Inheritance
-
- Object
- CommandResult
- SelectedResult
- SelectedWidget
Constructors
- SelectedWidget({required String description, String? location})
-
const
Properties
- description → String
-
The widget's description string (e.g.
"Text").final - hashCode → int
-
The hash code for this object.
no setterinherited
- location → String?
-
Optional source location in
"file.dart:42"or"file.dart"form.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited