PrefsGetFound class
get — key exists; value is whatever the VM returned (String/int/bool/double).
- Inheritance
-
- Object
- CommandResult
- SharedPrefsResult
- PrefsGetFound
Constructors
- PrefsGetFound(dynamic value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited