core/commands/swipe_path/swipe_path library

Classes

SwipePathAppDied
The app process died while fdb was communicating with it.
SwipePathError
Generic / unrecognised error.
SwipePathNoFdbHelper
fdb_helper was not detected in the running app.
SwipePathRelayedError
The VM extension returned a relayed error message.
SwipePathResult
Result of a runSwipePath invocation.
SwipePathSuccess
Swipe path succeeded.
SwipePathUnexpectedResponse
The VM service returned an unexpected response shape.

Functions

runSwipePath(SwipePathInput input, {FdbHelperChecker? checkFdbHelperFn, FdbSwipePathRunner? fdbSwipePathFn}) Future<SwipePathResult>
Sends a multi-point swipe path gesture to the running Flutter app via the VM service.

Typedefs

FdbHelperChecker = Future<String?> Function()
FdbSwipePathRunner = Future<FdbSwipePathCommandResponse> Function(Map<String, dynamic> params)
SwipePathInput = ({String points, double? precision})
Input parameters for runSwipePath.