SyslogStream class

The subprocess was started successfully.

lines emits one log line per event, already filtered by predicate. For non-follow mode, lines are also capped by last — the stream is finite and completes after the subprocess exits. For follow mode, the stream is infinite until cancel is called or the subprocess exits.

exitCode resolves to the subprocess exit code when the process terminates (0 if terminated via cancel).

cancel terminates the underlying subprocess (SIGTERM/kill). Safe to call multiple times.

Inheritance

Constructors

SyslogStream({required Stream<String> lines, required Future<int> exitCode, required Future<void> cancel()})
const

Properties

cancel Future<void> Function()
final
exitCode Future<int>
final
hashCode int
The hash code for this object.
no setterinherited
lines Stream<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited