SyslogToolMissing class

A required platform tool was not found on PATH.

Inheritance

Constructors

SyslogToolMissing({required String tool, required String hint})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hint String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tool String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited