core/commands/tree/tree_models library

Classes

TreeAppDied
The app process died while fdb was communicating with it.
TreeError
Generic / unrecognised error.
TreeNoIsolate
No Flutter isolate was found in the running app.
TreeNoWidgetTree
The VM service returned no widget tree (null or unexpected shape).
TreeReceived
Widget tree retrieved successfully; rootNode is the raw VM service map.
TreeResult
Result of a getWidgetTree invocation.

Typedefs

TreeInput = ({int maxDepth, bool userOnly})
Input parameters for getWidgetTree.