core/commands/wait/wait library

Classes

WaitAppDied
The app process died while fdb was communicating with it.
WaitConditionMet
The condition was met successfully.
WaitError
Generic / unrecognised error.
WaitNoFdbHelper
fdb_helper was not detected in the running app.
WaitRelayedError
The VM service returned an error message (e.g. timeout).
WaitResult
Result of a waitForWidget invocation.
WaitUnexpectedResponse
The VM service returned an unexpected response shape.

Enums

WaitCondition
The condition to wait for.

Functions

waitForWidget(WaitInput input) Future<WaitResult>
Waits until a widget or route is present or absent in the running Flutter app.

Typedefs

WaitInput = ({WaitCondition condition, String? key, String? route, String? text, int timeoutMs, String? type})
Input parameters for waitForWidget.