WaitConditionMet class
The condition was met successfully.
- Inheritance
-
- Object
- CommandResult
- WaitResult
- WaitConditionMet
Constructors
- WaitConditionMet({required WaitCondition condition, required String selectorToken})
-
const
Properties
- condition → WaitCondition
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectorToken → String
-
e.g. "KEY=foo" or "TEXT=bar"
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited