core/describe_ref library

Constants

helperTooOldForRefs → const String
Error for an @N request that reached an fdb_helper without describe refs.

Functions

refAwareError(String error, int? ref) → String
error from fdb_helper for a request with describe ref ref, or helperTooOldForRefs when the helper did not understand the ref param.