helperTooOldForRefs top-level constant
String
const helperTooOldForRefs
Error for an @N request that reached an fdb_helper without describe refs.
Implementation
const helperTooOldForRefs =
'fdb_helper in the app is too old for @N refs. Update fdb_helper to the version of fdb and rebuild the app.';