refAwareError function

String refAwareError(
  1. String error,
  2. int? ref
)

error from fdb_helper for a request with describe ref ref, or helperTooOldForRefs when the helper did not understand the ref param.

An fdb_helper without refs finds no selector in {ref: N} and rejects the request, so nothing was tapped or typed.

Implementation

String refAwareError(String error, int? ref) =>
    ref != null && error.contains('params must contain at least one of') ? helperTooOldForRefs : error;