LifecycleUnavailable class

The lifecycle could not be determined for a benign reason: no session, no fdb_helper, an older fdb_helper without ext.fdb.lifecycle, app died, or any other non-timeout failure. Callers stay silent.

Inheritance

Constructors

LifecycleUnavailable()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited