readAppPid function
Reads the app VM PID from appPidFile written by fdb launch after
the VM service is confirmed reachable.
Returns null if the file does not exist, its content is not a valid integer (e.g. the session was created by an older fdb version), or the PID is 0 or less.
Implementation
int? readAppPid() => _readPidFile(appPidFile);