xcrunExecutable top-level property
Executable used for every xcrun simctl ... invocation.
Mutable so tests can point it at a fake script.
Implementation
String xcrunExecutable = 'xcrun';
Executable used for every xcrun simctl ... invocation.
Mutable so tests can point it at a fake script.
String xcrunExecutable = 'xcrun';