CliCommand enum

Inheritance
Available extensions

Values

devices → const CliCommand
const CliCommand('devices', runDevicesCli)
const CliCommand('deeplink', runDeeplinkCli)
launch → const CliCommand
const CliCommand('launch', null)
reload → const CliCommand
const CliCommand('reload', runReloadCli)
restart → const CliCommand
const CliCommand('restart', runRestartCli)
screenshot → const CliCommand
const CliCommand('screenshot', runScreenshotCli)
logs → const CliCommand
const CliCommand('logs', runLogsCli)
syslog → const CliCommand
const CliCommand('syslog', runSyslogCli)
crashReport → const CliCommand
const CliCommand('crash-report', runCrashReportCli)
tree → const CliCommand
const CliCommand('tree', runTreeCli)
describe → const CliCommand
const CliCommand('describe', runDescribeCli)
doctor → const CliCommand
const CliCommand('doctor', runDoctorCli)
nativeTap → const CliCommand
const CliCommand('native-tap', runNativeTapCli)
tap → const CliCommand
const CliCommand('tap', runTapCli)
doubleTap → const CliCommand
const CliCommand('double-tap', runDoubleTapCli)
longpress → const CliCommand
const CliCommand('longpress', runLongpressCli)
input → const CliCommand
const CliCommand('input', runInputCli)
scroll → const CliCommand
const CliCommand('scroll', runScrollCli)
scrollTo → const CliCommand
const CliCommand('scroll-to', runScrollToCli)
wait → const CliCommand
const CliCommand('wait', runWaitCli)
swipe → const CliCommand
const CliCommand('swipe', runSwipeCli)
back → const CliCommand
const CliCommand('back', runBackCli)
clean → const CliCommand
const CliCommand('clean', runCleanCli)
sharedPrefs → const CliCommand
const CliCommand('shared-prefs', runSharedPrefsCli)
ext → const CliCommand
const CliCommand('ext', runExtCli)
select → const CliCommand
const CliCommand('select', runSelectCli)
selected → const CliCommand
const CliCommand('selected', runSelectedCli)
status → const CliCommand
const CliCommand('status', runStatusCli)
kill → const CliCommand
const CliCommand('kill', runKillCli)
mem → const CliCommand
const CliCommand('mem', runMemCli)
gc → const CliCommand
const CliCommand('gc', runGcCli)
grantPermission → const CliCommand
const CliCommand('grant-permission', runGrantPermissionCli)
simulator → const CliCommand
const CliCommand('simulator', runSimulatorCli)
skill → const CliCommand
const CliCommand('skill', runSkillCli)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runner CliRunner?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWireName(String? value) CliCommand?

Constants

values → const List<CliCommand>
A constant List of the values in this enum, in order of their declaration.