core/app_died_exception library

Functions

buildAppDiedException({int? pid}) Future<AppDiedException>
Builds an AppDiedException by reading the log tail and, when possible, performing a best-effort OS-level reason lookup.
readLastLogLines() List<String>
Reads the last _logTailLines lines from .fdb/logs.txt.

Exceptions / Errors

AppDiedException
Thrown when the target Flutter app process has died while fdb is trying to communicate with it via the VM service.