core/commands/attach/attach
library
Functions
-
attachApp(AttachInput input, {void onProgress(String) = _noop})
→ Future<AttachResult>
-
Attaches fdb to an already-running Flutter app and waits for the VM service.
-
buildAttachControllerArgs(List<String> controllerEntrypointArgs, {required String sessionDir, required String project, required String device, required String flutter, String? target, String? appId, String? debugUrl, required bool verbose})
→ List<String>
-
-
discoverVmServiceUrl({required String device, required ({bool emulator, String platform}) platformInfo, Duration timeout = const Duration(seconds: 5), void onProgress(String) = _noop})
→ Future<String?>
-
Attempts to discover the Dart VM service URL for a Flutter app that was
launched outside of fdb by scanning the relevant device log.
-
normalizeAttachDebugUrl(String debugUrl)
→ String
-