BackAtRoot class
Nothing in the app handled the back press (already at the root screen).
passedToOs is true when fdb_helper then passed it to the OS like a real back press (Android: the app leaves the foreground), false on platforms without a system back button, null from older fdb_helper versions.
- Inheritance
-
- Object
- CommandResult
- BackResult
- BackAtRoot
Constructors
- BackAtRoot({bool? passedToOs})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- passedToOs → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited