core/commands/double_tap/double_tap library
Classes
- DoubleTapAppDied
- The app process died while fdb was communicating with it.
- DoubleTapError
- Generic / unrecognised error.
- DoubleTapNoFdbHelper
- fdb_helper was not detected in the running app.
- DoubleTapRelayedError
- The VM service returned an error message (after retries).
- DoubleTapResult
- Result of a doubleTap invocation.
- DoubleTapSuccess
- The double-tap succeeded.
- DoubleTapUnexpectedResponse
- The VM service returned an unexpected response shape.
Functions
-
doubleTap(
DoubleTapInput input) → Future< DoubleTapResult> - Double-taps a widget identified by selector or absolute coordinates.