ExtCallInput class

Input for fdb ext call <method> [--arg key=value ...].

Inheritance

Constructors

ExtCallInput({required String method, required Map<String, String> args})
const

Properties

args Map<String, String>
Key/value parameters forwarded to the extension (may be empty).
final
hashCode int
The hash code for this object.
no setterinherited
method String
Fully-qualified extension method name, e.g. ext.flutter.imageCache.size.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited