GcSuccess class

GC completed successfully across at least one isolate.

Inheritance

Constructors

GcSuccess({required int heapBefore, required int heapAfter, required int heapDelta, List<String> warnings = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
heapAfter → int
Total heap usage in bytes after GC (summed across all isolates).
final
heapBefore → int
Total heap usage in bytes before GC (summed across all isolates).
final
heapDelta → int
Delta in bytes (heapAfter - heapBefore; negative means reclaimed).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warnings → List<String>
Per-isolate warning messages for isolates that failed to GC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited