core/commands/input/input library

Classes

InputAppDied
The app process died while fdb was communicating with it.
InputError
Generic / unrecognised error.
InputNoFdbHelper
fdb_helper was not detected in the running app.
InputRelayedError
The VM service returned an error message.
InputResult
Result of an enterText invocation.
InputSuccess
Text was successfully entered; fieldType is the widget type string.
InputUnexpectedResponse
The VM service returned an unexpected response shape.

Functions

enterText(InputInput input) Future<InputResult>
Enters text into a field in the running Flutter app.

Typedefs

InputInput = ({int? index, String? key, String? text, String textToEnter, String? type})
Input parameters for enterText.