InputSuccess class
Text was entered and/or an IME action was sent.
fieldType is the widget type string. value is the entered text (null when only an action was sent). action is the IME action performed, if any. clientType is the State that received the input (e.g. EditableTextState, QuillRawEditorState).
- Inheritance
-
- Object
- CommandResult
- InputResult
- InputSuccess
Constructors
- InputSuccess({required String fieldType, required String? value, String? action, String? clientType})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited