InputSuccess class

Text was successfully entered; fieldType is the widget type string.

Inheritance

Constructors

InputSuccess({required String fieldType, required String value})
const

Properties

fieldType String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited