LaunchSuccess class
App launched successfully. VM service is reachable at vmServiceUri.
- Inheritance
-
- Object
- CommandResult
- LaunchResult
- LaunchSuccess
Constructors
- LaunchSuccess({required String vmServiceUri, required String pid, required String logFilePath})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logFilePath → String
-
final
- pid → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vmServiceUri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited