ClassDiff class

A single class diff entry (after − before).

Constructors

ClassDiff({required String className, required String libraryUri, required int instancesBefore, required int instancesAfter, required int bytesBefore, required int bytesAfter})
const

Properties

bytesAfter int
final
bytesBefore int
final
bytesDelta int
no setter
className String
final
hashCode int
The hash code for this object.
no setterinherited
instanceDelta int
no setter
instancesAfter int
final
instancesBefore int
final
libraryUri String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited