IsolateHeapInfo class
One isolate's heap snapshot returned by getMemoryUsage.
Constructors
Properties
- externalUsage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heapCapacity → int
-
final
- heapUsage → int
-
final
- id → String
-
VM isolate ID (e.g.
isolates/123). Use this as the--isolatevalue.final - name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited