MemProfileMultiSuccess class

Profiles captured and written to disk for multiple isolates.

Inheritance

Constructors

MemProfileMultiSuccess({required List<String> outputPaths, required List<String> isolateNames, required int classCount})
const

Properties

classCount int
Total class count across all isolates.
final
hashCode int
The hash code for this object.
no setterinherited
isolateNames List<String>
Isolate name for each written file (parallel to outputPaths).
final
outputPaths List<String>
Actual file paths written, one per isolate (parallel to isolateNames).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited