MemSuccess class

Successfully retrieved per-isolate heap info.

Inheritance

Constructors

MemSuccess(List<IsolateHeapInfo> isolates)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isolates List<IsolateHeapInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited