ScreenshotSaved class
Screenshot was captured, optionally downscaled, and saved to path.
- Inheritance
-
- Object
- CommandResult
- ScreenshotResult
- ScreenshotSaved
Constructors
-
ScreenshotSaved({required String path, required int sizeBytes, List<
String> warnings = const []}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited