ScrollDirectionMode class

Direction-based scroll: fdb scroll down [--at x,y] [--distance pixels].

Inheritance

Constructors

ScrollDirectionMode({required String direction, String? at, int distance = 200})
const

Properties

at String?
Raw "x,y" string passed through to the VM extension unchanged.
final
direction String
One of 'up', 'down', 'left', 'right'.
final
distance int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited