core/commands/select/select_models library

Classes

SelectAppDied
The app process died while fdb was communicating with it.
SelectError
Generic / unrecognised error.
SelectNoIsolate
No Flutter isolate was found in the running app.
SelectResult
Result of a toggleSelection invocation.
SelectSuccess
The selection mode was toggled successfully.

Typedefs

SelectInput = ({bool enabled})
Input parameters for toggleSelection.