core/commands/swipe/swipe library
Classes
- SwipeAppDied
- The app process died while fdb was communicating with it.
- SwipeError
- Generic / unrecognised error.
- SwipeNoFdbHelper
- fdb_helper was not detected in the running app.
- SwipeRelayedError
- The VM extension returned a relayed error message.
- SwipeResult
- Result of a runSwipe invocation.
- SwipeSuccess
- Swipe succeeded.
- SwipeUnexpectedResponse
- The VM service returned an unexpected response shape.
Functions
-
runSwipe(
SwipeInput input, {FdbHelperChecker? checkFdbHelperFn, FdbSwipeRunner? fdbSwipeFn}) → Future< SwipeResult> - Sends a swipe gesture to the running Flutter app via the VM service.
Typedefs
-
FdbHelperChecker
= Future<
String?> Function() -
FdbSwipeRunner
= Future<
FdbSwipeCommandResponse> Function(Map<String, dynamic> params) - SwipeInput = ({String? at, String direction, int? distance, String? key, String? text, String? type})
- Input parameters for runSwipe.