SwipeSuccess class

Swipe succeeded.

Inheritance

Constructors

SwipeSuccess({required String direction, required dynamic actualDistance})
const

Properties

actualDistance → dynamic
The distance returned by the VM extension, or the requested distance, or an empty string when neither is available.
final
direction → String
Direction in lowercase (e.g. "left").
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited