core/commands/syslog/syslog library
Classes
- SyslogError
- A platform-level or validation error prevented syslog from running.
- SyslogResult
- SyslogStream
- The subprocess was started successfully.
- SyslogToolMissing
- A required platform tool was not found on PATH.
Functions
-
runSyslog(
SyslogInput input) → Future< SyslogResult> - Reads native system logs from the device under debug.