SyslogStream class
The subprocess was started successfully.
lines emits one log line per event, already filtered by predicate.
For non-follow mode, lines are also capped by last — the stream is finite
and completes after the subprocess exits.
For follow mode, the stream is infinite until cancel is called or the
subprocess exits.
exitCode resolves to the subprocess exit code when the process terminates (0 if terminated via cancel).
cancel terminates the underlying subprocess (SIGTERM/kill). Safe to call multiple times.
- Inheritance
-
- Object
- CommandResult
- SyslogResult
- SyslogStream
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited