TapSuccess class

Inheritance

Constructors

TapSuccess({required String widgetType, required dynamic x, required dynamic y, String? warning, String? text})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
For @N taps: the text fdb describe shows for the tapped widget.
final
warning → String?
final
widgetType → String
final
x → dynamic
final
y → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited