RunningHelperVersion class sealed
What the running app reported about its fdb_helper version.
Constructors
-
RunningHelperVersion.fromPayload(Map<
String, dynamic> payload) -
Reads the version from an
ext.fdb.describe/ext.fdb.lifecyclepayload. A payload without the field comes from a pre-1.13 helper.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited