core/vm_lifecycle_events library

Functions

isFlutterFirstFrameEvent(Map<String, dynamic> event) bool
Returns true when the VM event reports the first frame after restart.
isFlutterFrameEvent(Map<String, dynamic> event) bool
Returns true when the VM event reports a post-reload Flutter frame.
isFlutterServiceExtensionStateChangedEvent(Map<String, dynamic> event) bool
Returns true when the VM event reports a service extension state change.
isIsolateRunnableEvent(Map<String, dynamic> event) bool
Returns true when the VM event signals that an isolate became runnable.
isReloadCompletionEvent(Map<String, dynamic> event) bool
Returns true when the VM event signals that a hot reload has completed.
isRestartCompletionEvent(Map<String, dynamic> event) bool
Returns true when the VM event signals that a hot restart has completed.
waitForVmEventAfterSignal({required List<String> streamIds, required VmEventMatcher matches, required void signal(), required Duration timeout}) Future<bool>
Subscribes to VM service streams, sends signal, then waits for a matching event or timeout.
waitForVmServiceEvent({required Stream<Map<String, dynamic>> events, required VmEventMatcher matches, required Duration timeout}) Future<bool>
Waits for the first VM event that satisfies matches.

Typedefs

VmEventMatcher = bool Function(Map<String, dynamic> event)